import rfc822_message_parse
import rfc822_message
import rfc822_address
import rfc822_attachment
import cStringIO
import time


def store_message(container, message):
	"""A method that adds an rfc822_message object
	to the container, and possibly address fields.
	It may also add attachments."""

	message_id = str(container.get_id())

	if message.attachments:

		message_id = message_id + '_attachments'

	rfc822_message.manage_add_rfc822_message(container, message_id,
											 message.to, message.sender,
											 message.reply_to, message.cc,
											 message.bcc, message.newsgroups,
											 message.body, message.subject,
											 headers = message.headers)

	message_reference = container[message_id]

	# We need to instansiate classes first; and then add them to the ZODB,
	# because ZOPE hangs otherwise.. strange.

	#bcc_address = rfc822_address.rfc822_address('test', 'morten@esol.no', 'comment', 'realname')

	#message_reference['bcc']._setObject('test', bcc_address)

	if message.to:

		for address_field in message.to:

			id = str(container.get_id())

			message_reference['to'].manage_addFolder(id)
			message_reference['to'].address = address_field[-1]
			message_reference['to'].realname = 'realname'
			message_reference['to'].comment = 'comment'

	if message.cc:

		for address_field in message.cc:

			id = str(container.get_id())

			message_reference['cc'].manage_addFolder(id)
			message_reference['cc'].address = address_field[-1]
			message_reference['cc'].realname = 'realname'
			message_reference['cc'].comment = 'comment'


	if message.bcc:

		for address_field in message.bcc:

			id = str(container.get_id())

			message_reference['bcc'].manage_addFolder(id)
			message_reference['bcc'].address = address_field[-1]
			message_reference['bcc'].realname = 'realname'
			message_reference['bcc'].comment = 'comment'			


	for attachment in message.attachments:

		rfc822_attachment.manage_add_rfc822_attachment(
			message_reference, str(container.get_id()),
			data = attachment.data, headers = attachment.headers,
			content_type = attachment.media_type + '/' + attachment.sub_type,
			filename = attachment.filename)
													   


def store_unparsed_message(container, unparsed_rfc822_message):
	"""This method lets us parse a message before storing it."""

	if type(unparsed_rfc822_message) is type(''):

		unparsed_rfc822_message = my_string_io(unparsed_rfc822_message)

	message = rfc822_message_parse.rfc822_message_parse(
		unparsed_rfc822_message)

	store_message(container, message)


class my_string_io:
	"""This class represents a wrapper for a cStringIO.StringIO instance, giving
	the ability to use the readlines method."""

	# Should we use a __getattr__ wrapper instead of per-method wrapping?
	# This will prevent breakage of future methods StringIO may have...

	def __init__(self, data=''):

		self._fp = cStringIO.StringIO(data)


	def close(self):

		return self._fp.close()


	def flush(self):

		return self._fp.flush()


	def isatty(self):

		return self._fp.isatty()


	def fileno(self):

		return self._fp.fileno()


	def read(self, size=None):

		if size:

			return self._fp.read(size)

		return self._fp.read()


	def readline(self):

		return self._fp.readline()


	def readlines(self):

		return_list = []

		tmp = None

		while 1:

			tmp = self._fp.readline()

			if tmp:

				return_list.append(tmp)

			else:

				break

		return return_list


	def seek(self, offset, whence=None):

		if whence:

			return self._fp.seek(offset, whence)

		return self._fp.seek(offset)


	def tell(self):

		return self._fp.tell()


	def truncate(self, size=None):

		if size:
			
			return self._fp.truncate(size)

		return self._fp.truncate()


	def write(self, _string):

		return self._fp.write(_string)


	def writelines(self, lines):

		return self._fp.writelines(lines)
