###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.0 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import default__class_init__
from OFS.DTMLMethod import addDTMLMethod
import Acquisition
import AccessControl.Role
import OFS.Folder
import Products

import category

todofolderAdd2 = HTMLFile('todofolderAdd2', globals())
manage_addTodoFolderForm = HTMLFile('todofolderAdd', globals())


def manage_addTodoFolder(self, id, title, REQUEST=None):
    "Add an instance of the TodoFolder class"

    self._setObject(id, TodoFolder(id, title))

    if REQUEST is not None:

        return self.manage_main(self, REQUEST)


class TodoFolder(
	Products.ZCatalog.CatalogAwareness.CatalogAware,
	OFS.Folder.Folder,
	Persistent,
	Acquisition.Implicit,
	AccessControl.Role.RoleManager
	):
	"Documentation string"

	meta_type = 'TodoFolder'
	icon = 'misc_/TodoFolder/Folder_icon.gif'
	default_catalog = 'Catalog'

	_properties = (
		{'id':'title', 'type':'string'},
		)

	meta_types = (
		{'name':'Category', 'action':'manage_addCategoryForm'},
		)

	manage_addCategoryForm = category.manage_addCategoryForm
	manage_addCategory = category.manage_addCategory
	categoryAdd2 = category.categoryAdd2

	__ac_permissions__ = (
		('View management screens',
		 ('manage_tabs', 'manage_main')),
		('Change Permissions',
		 ('manage_access',)),
		('Add Category',
		 ('manage_addCategory', 'manage_addCategoryForm')),
		('View TodoFolders',
		 ('',)),
		)

	index_html = HTMLFile('todofolderIndex', globals())


	def __init__(self, id, title=''):
		"Initialize the class instance"

		self.id = id
		self.title = title
		self.index_object()

		self.counter = 0

		addDTMLMethod(self, 'standard_html_header', 'Standard HTML Header',
					  """<html><head><title></title></head><body>""")

		addDTMLMethod(self, 'standard_html_footer', 'Standard HTML Footer',
					  """</body></html>""")


	def get_unique_id(self):
		"""Returns a unique identifier."""

		self.counter = self.counter + 1

		return str(self.counter)


	def delete(self, ids=[], RESPONSE=None, REQUEST=None):

		self.manage_delObjects(ids)

		RESPONSE.redirect(REQUEST['HTTP_REFERRER'])


	def edit(self, REQUEST=None, RESPONSE=None):
		"""Updates the properties."""

		tmp = {}
		
		for key, value in REQUEST.form.keys():

			self.manageChangeProperties(key=value)


	def display(self):
		"""Displays a view suitable in a larger picture."""

		return_string = """<table border="0">
		<tr>
		<th colspan="2"><a href="%s">Todos</a></th>
		</tr>
		""" % self.absolute_url()

		for category in self.objectValues('Category'):

			number_of_todos = len(category.objectValues('Todo'))

			if number_of_todos:

				number_of_todos_rendered = "(%s)" % number_of_todos

			else:

				number_of_todos_rendered = ""

			return_string = return_string + """<tr>
			<td>&nbsp;&nbsp;</td><td><a href="%s">%s %s</a></td></tr>""" % (
				category.absolute_url(), category.title, number_of_todos_rendered)

		return_string = return_string + """</table>"""

		return return_string


default__class_init__(TodoFolder)

